searchData={"items":[{"type":"module","title":"RingLogger","doc":"This is an in-memory ring buffer backend for the Elixir Logger.\n\nInstall it by adding it to your `config.exs`:\n\n```elixir\nuse Mix.Config\n\n# Add the RingLogger backend. This removes the default :console backend.\nconfig :logger, backends: [RingLogger]\n\n# Periodically save logs to a file, and load logs on GenServer start from this file\nconfig :logger, RingLogger, persist_path: \"./myapp.log\", persist_seconds: 300\n\n# Save messages to one circular buffer that holds 1024 entries.\nconfig :logger, RingLogger, max_size: 1024\n\n# Separate out `:error` and `:warning` messages to their own circular buffer.\n# All other log messages are stored in the default circular buffer.\nconfig :logger, RingLogger, buffers: %{\n  errors: %{\n    levels: [:error, :warning],\n    max_size: 1024\n  }\n}\n\n# Specify circular buffers for all log levels. The default circular buffer won't\n# be used in this example configuration.\nconfig :logger, RingLogger, buffers: %{\n  low_priority: %{\n    levels: [:warning, :notice, :info, :debug],\n    max_size: 1024\n  },\n  high_priority: %{\n    levels: [:emergency, :alert, :critical, :error],\n    max_size: 1024\n  }\n}\n```\n\nOr add manually:\n\n```elixir\nLogger.add_backend(RingLogger)\nLogger.configure_backend(RingLogger, max_size: 1024)\n```\n\nOnce added as a backend, you have two options depending on whether you're\naccessing the `RingLogger` via the IEx prompt or via code.  If you're at the\nIEx prompt, use the helper methods in here like `attach`, `detach`, `next`,\n`tail`, `grep`, etc. They'll automate a few things behind the scenes. If\nyou're writing a program that needs to get log messages, use `get` or\n`start_link` a `RingLogger.Client` and call its methods directly.","ref":"RingLogger.html"},{"type":"function","title":"RingLogger.attach/1","doc":"Attach the current IEx session to the logger. It will start printing log messages.\n\nOptions include:\n\n* `:io` - output location when printing. Defaults to `:stdio`\n* `:colors` - a keyword list of coloring options\n* `:metadata` - a keyword list of additional metadata\n* `:format` - the format message used to print logs\n* `:level` - the minimum log level to report by this backend. Note that the `:logger`\n  application's `:level` setting filters log messages prior to `RingLogger`.\n* `:module_levels` - a map of log level overrides per module. For example,\n  %{MyModule => :error, MyOtherModule => :none}\n* `:application_levels` - a map of log level overrides per application. For example,\n  %{:my_app => :error, :my_other_app => :none}. Note log levels set in `:module_levels`\n  will take precedence.","ref":"RingLogger.html#attach/1"},{"type":"function","title":"RingLogger.config/0","doc":"Fetch the current configuration for the attached client","ref":"RingLogger.html#config/0"},{"type":"function","title":"RingLogger.configure/1","doc":"Update the logger configuration.\n\nOptions include:\n* `:max_size` - the max number of log messages to store at a time","ref":"RingLogger.html#configure/1"},{"type":"function","title":"RingLogger.count_next/1","doc":"Count the next messages in the log\n\nNOTE: This function may change in future releases.\n\nOptions include:\n\n* Options from `attach/1`\n* `:pager` - a function for printing log messages to the console. Defaults to `IO.binwrite/2`.","ref":"RingLogger.html#count_next/1"},{"type":"function","title":"RingLogger.detach/0","doc":"Detach the current IEx session from the logger","ref":"RingLogger.html#detach/0"},{"type":"function","title":"RingLogger.format/1","doc":"Helper method for formatting log messages per the current client's\nconfiguration.","ref":"RingLogger.html#format/1"},{"type":"function","title":"RingLogger.get/2","doc":"Get n log messages starting at the specified index.\n\nSet n to 0 to get entries to the end","ref":"RingLogger.html#get/2"},{"type":"function","title":"RingLogger.grep/2","doc":"Run a regular expression on each entry in the log and print out the matchers.\n\nFor example:\n\niex> RingLogger.grep(~r/something/)\n:ok\n\n  Options include:\n\n* Options from `attach/1`\n* `:pager` - a function for printing log messages to the console. Defaults to `IO.binwrite/2`.\n* `:before` - Number of lines before the match to include\n* `:after` - NUmber of lines after the match to include","ref":"RingLogger.html#grep/2"},{"type":"function","title":"RingLogger.grep_metadata/2","doc":"Return a list of formatted log entries that match the given metadata key-value pair.\n\nFor example:\n\niex> RingLogger.grep_metadata(:session_id, \"abc\")\n:ok\n\niex> RingLogger.grep_metadata(:session_id, ~r/something/)\n:ok","ref":"RingLogger.html#grep_metadata/2"},{"type":"function","title":"RingLogger.next/1","doc":"Print the next messages in the log\n\nOptions include:\n\n* Options from `attach/1`\n* `:pager` - a function for printing log messages to the console. Defaults to `IO.binwrite/2`.","ref":"RingLogger.html#next/1"},{"type":"function","title":"RingLogger.reset/1","doc":"Reset the index into the log for `next/1` to the oldest entry.","ref":"RingLogger.html#reset/1"},{"type":"function","title":"RingLogger.save/1","doc":"Save the contents of the log to the specified path\n\nThe file is overwritten if it already exists. Log message\nformatting is done similarly to other RingLogger calls.","ref":"RingLogger.html#save/1"},{"type":"function","title":"RingLogger.tail/0","doc":"Print the last 10 messages","ref":"RingLogger.html#tail/0"},{"type":"function","title":"RingLogger.tail/1","doc":"Print the last messages in the log\n\nSee `tail/2`.","ref":"RingLogger.html#tail/1"},{"type":"function","title":"RingLogger.tail/2","doc":"Print the last n messages in the log\n\nOptions include:\n\n* Options from `attach/1`\n* `:pager` - a function for printing log messages to the console. Defaults to `IO.binwrite/2`.","ref":"RingLogger.html#tail/2"},{"type":"function","title":"RingLogger.viewer/0","doc":"Starts the Ring Logger Viewer TUI app on the current prompt","ref":"RingLogger.html#viewer/0"},{"type":"type","title":"RingLogger.buffer/0","doc":"Options to define a separate buffer based on log levels","ref":"RingLogger.html#t:buffer/0"},{"type":"type","title":"RingLogger.client_option/0","doc":"Option values used by client-side functions like `attach` and `tail`","ref":"RingLogger.html#t:client_option/0"},{"type":"type","title":"RingLogger.client_options/0","doc":"Option list for client-side functions","ref":"RingLogger.html#t:client_options/0"},{"type":"type","title":"RingLogger.entry/0","doc":"A map holding a raw, unformatted log entry","ref":"RingLogger.html#t:entry/0"},{"type":"type","title":"RingLogger.pager_fun/0","doc":"Callback function for printing/paging tail, grep, and next output","ref":"RingLogger.html#t:pager_fun/0"},{"type":"type","title":"RingLogger.server_option/0","doc":"Option values used by the ring logger","ref":"RingLogger.html#t:server_option/0"},{"type":"module","title":"RingLogger.Autoclient","doc":"Helper module for `RingLogger.Client` to simplify IEx use\n\nIf you're a human, call these functions via `RingLogger.*`. If you're a\nprogram, call `RingLogger.Client.start_link/1` to start your own client and\ncall it directly.","ref":"RingLogger.Autoclient.html"},{"type":"function","title":"RingLogger.Autoclient.attach/1","doc":"Attach to the logger and print messages as they come in.","ref":"RingLogger.Autoclient.html#attach/1"},{"type":"function","title":"RingLogger.Autoclient.config/0","doc":"Fetch the current configuration for the attached client.","ref":"RingLogger.Autoclient.html#config/0"},{"type":"function","title":"RingLogger.Autoclient.count_next/1","doc":"Print the log message count since the previous time this was called.","ref":"RingLogger.Autoclient.html#count_next/1"},{"type":"function","title":"RingLogger.Autoclient.detach/0","doc":"Detach from the logger. Log messages will stop being printed to the console.","ref":"RingLogger.Autoclient.html#detach/0"},{"type":"function","title":"RingLogger.Autoclient.forget/0","doc":"Completely stop the RingLogger.Client. You normally don't need to run this.","ref":"RingLogger.Autoclient.html#forget/0"},{"type":"function","title":"RingLogger.Autoclient.format/1","doc":"Format a log message. This is useful if you're calling `RingLogger.get/1` directly.","ref":"RingLogger.Autoclient.html#format/1"},{"type":"function","title":"RingLogger.Autoclient.grep/2","doc":"Run a regular expression on each entry in the log and print out the matchers.","ref":"RingLogger.Autoclient.html#grep/2"},{"type":"function","title":"RingLogger.Autoclient.grep_metadata/2","doc":"Return a list of formatted log entries that match the given metadata key-value pair.","ref":"RingLogger.Autoclient.html#grep_metadata/2"},{"type":"function","title":"RingLogger.Autoclient.next/1","doc":"Print the log messages since the previous time this was called.","ref":"RingLogger.Autoclient.html#next/1"},{"type":"function","title":"RingLogger.Autoclient.reset/1","doc":"Reset the index used to keep track of the position in the log for `tail/1` so\nthat the next call to `tail/1` starts back at the oldest entry.","ref":"RingLogger.Autoclient.html#reset/1"},{"type":"function","title":"RingLogger.Autoclient.save/1","doc":"Save the log.","ref":"RingLogger.Autoclient.html#save/1"},{"type":"function","title":"RingLogger.Autoclient.tail/2","doc":"Print the most recent log messages.","ref":"RingLogger.Autoclient.html#tail/2"},{"type":"module","title":"RingLogger.Client","doc":"Interact with the RingLogger","ref":"RingLogger.Client.html"},{"type":"function","title":"RingLogger.Client.attach/1","doc":"Attach the current IEx session to the logger. It will start printing log messages.","ref":"RingLogger.Client.html#attach/1"},{"type":"function","title":"RingLogger.Client.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"RingLogger.Client.html#child_spec/1"},{"type":"function","title":"RingLogger.Client.config/1","doc":"Fetch the current client configuration.","ref":"RingLogger.Client.html#config/1"},{"type":"function","title":"RingLogger.Client.configure/2","doc":"Update the client configuration.\n\nOptions include:\n* `:io` - Defaults to `:stdio`\n* `:colors` -\n* `:metadata` - A KV list of additional metadata\n* `:format` - A custom format string, or a {module, function} tuple (see\n  https://hexdocs.pm/logger/master/Logger.html#module-custom-formatting)\n* `:level` - The minimum log level to report.\n* `:module_levels` - a map of log level overrides per module. For example,\n  %{MyModule => :error, MyOtherModule => :none}\n* `:application_levels` - a map of log level overrides per application. For example,\n  %{:my_app => :error, :my_other_app => :none}. Note log levels set in `:module_levels`\n  will take precedence.","ref":"RingLogger.Client.html#configure/2"},{"type":"function","title":"RingLogger.Client.configure_module_levels/1","doc":"","ref":"RingLogger.Client.html#configure_module_levels/1"},{"type":"function","title":"RingLogger.Client.count_next/1","doc":"Count the next set of the messages in the log.","ref":"RingLogger.Client.html#count_next/1"},{"type":"function","title":"RingLogger.Client.detach/1","doc":"Detach the current IEx session from the logger.","ref":"RingLogger.Client.html#detach/1"},{"type":"function","title":"RingLogger.Client.format/2","doc":"Helper method for formatting log messages per the current client's\nconfiguration.","ref":"RingLogger.Client.html#format/2"},{"type":"function","title":"RingLogger.Client.grep/3","doc":"Run a regular expression on each entry in the log and print out the matchers.\n\nSupported options:\n\n* `:pager` - an optional 2-arity function that takes an IO device and what to print\n* `:before` - Number of lines before the match to include\n* `:after` - NUmber of lines after the match to include","ref":"RingLogger.Client.html#grep/3"},{"type":"function","title":"RingLogger.Client.grep_metadata/4","doc":"","ref":"RingLogger.Client.html#grep_metadata/4"},{"type":"function","title":"RingLogger.Client.next/2","doc":"Get the next set of the messages in the log.\n\nSupported options:\n\n* `:pager` - an optional 2-arity function that takes an IO device and what to print","ref":"RingLogger.Client.html#next/2"},{"type":"function","title":"RingLogger.Client.reset/1","doc":"Reset the index into the log for `tail/1` to the oldest entry.","ref":"RingLogger.Client.html#reset/1"},{"type":"function","title":"RingLogger.Client.save/2","doc":"Format and save all log messages to the specified path.","ref":"RingLogger.Client.html#save/2"},{"type":"function","title":"RingLogger.Client.start_link/1","doc":"Start up a client GenServer. Except for just getting the contents of the ring buffer, you'll\nneed to create one of these. See `configure/2` for information on options.","ref":"RingLogger.Client.html#start_link/1"},{"type":"function","title":"RingLogger.Client.stop/1","doc":"Stop a client.","ref":"RingLogger.Client.html#stop/1"},{"type":"function","title":"RingLogger.Client.tail/3","doc":"Get the last n messages.\n\nSupported options:\n\n* `:pager` - an optional 2-arity function that takes an IO device and what to print","ref":"RingLogger.Client.html#tail/3"},{"type":"module","title":"RingLogger.Viewer","doc":"A Terminal UI (TUI) based viewer to browse a snapshot of the RingLogger buffer.\nOffers a variety of filtering tools.\n\nStart the viewer using the following line at the IEx prompt:\n\n```\nRingLogger.viewer()\n```\n\nType `help`, `h` or `?` at the log viewer prompt to open a help page.\nType `exit` or `e` to exit the viewer.","ref":"RingLogger.Viewer.html"},{"type":"function","title":"RingLogger.Viewer.view/0","doc":"","ref":"RingLogger.Viewer.html#view/0"},{"type":"extras","title":"ring_logger","doc":"# ring_logger\n\n[![CircleCI](https://circleci.com/gh/nerves-project/ring_logger.svg?style=svg)](https://circleci.com/gh/nerves-project/ring_logger)\n[![Hex version](https://img.shields.io/hexpm/v/ring_logger.svg \"Hex version\")](https://hex.pm/packages/ring_logger)\n\nThis is an in-memory ring buffer backend for the [Elixir\nLogger](https://hexdocs.pm/logger/Logger.html) with convenience methods for\naccessing the logs from the IEx prompt.\n\nUse cases:\n\n* Get log messages in real-time over remote IEx sessions\n* Grep and tail through log messages without setting up anything else\n* Keep logs in limited resource environments\n* Capture recent log events for error reports\n\nAs a bonus, `ring_logger` is nice to your IEx prompt. If you attach to the log\nand are receiving messages as they're sent, they won't stomp what you're typing.","ref":"readme.html"},{"type":"extras","title":"Configuration - ring_logger","doc":"Add `ring_logger` to your projects dependencies in your `mix.exs`:\n\n```elixir\n  def deps do\n    [{:ring_logger, \"~> 0.6\"}]\n  end\n```\n\nThen configure the logger in your `config/config.exs`:\n\n```elixir\nuse Mix.Config\n\n# Add the RingLogger backend. This removes the default :console backend.\nconfig :logger, backends: [RingLogger]\n\n# Periodically save logs to a file, and load logs on GenServer start from this file\nconfig :logger, RingLogger, persist_path: \"./myapp.log\", persist_seconds: 300\n\n# Save messages to one circular buffer that holds 1024 entries.\nconfig :logger, RingLogger, max_size: 1024\n\n# Separate out `:error` and `:warning` messages to their own circular buffer.\n# All other log messages are stored in the default circular buffer.\nconfig :logger, RingLogger, buffers: %{\n  errors: %{\n    levels: [:error, :warning],\n    max_size: 1024\n  }\n}\n\n# Specify circular buffers for all log levels. The default circular buffer won't\n# be used in this example configuration.\nconfig :logger, RingLogger, buffers: %{\n  low_priority: %{\n    levels: [:warning, :notice, :info, :debug],\n    max_size: 1024\n  },\n  high_priority: %{\n    levels: [:emergency, :alert, :critical, :error],\n    max_size: 1024\n  }\n}\n\n# You can also configure `RingLogger.Client` options to be used\n# with every client by default\nconfig :logger, RingLogger,\n  application_levels: %{my_app: :error},\n  colors: [debug: :yellow],\n  level: :debug\n```\n\nOr you can start the backend manually by running the following:\n\n```elixir\nLogger.add_backend(RingLogger)\nLogger.configure_backend(RingLogger, max_size: 1024)\n```","ref":"readme.html#configuration"},{"type":"extras","title":"IEx session usage - ring_logger","doc":"See the example project for a hands-on walk-through of using the logger. Read on\nfor the highlights.\n\nFor the purpose of the example, when you're in IEx, log messages shouldn't be\nprinted to the console by default. They'll be coming from the console logger, so\nturn them off:\n\n```elixir\niex> Logger.remove_backend(:console)\n:ok\n```\n\nTo see log messages as they come in with RingLogger, call `RingLogger.attach()`\nand then to make the log messages stop, call `RingLogger.detach()`. The `attach`\nmethod takes options if you want to limit the log level, change the formatting,\netc.\n\nHere's an example:\n\n```elixir\niex> Logger.add_backend(RingLogger)\n{:ok, #PID<0.199.0>}\niex> RingLogger.attach\n:ok\niex> require Logger\niex> Logger.info(\"hello\")\n:ok\n\n14:04:52.516 [info]  hello\n```\n\nIf you prefer polling for log messages rather than having them print when they\nshow up. If you're still attached, then `detach` and `next`:\n\n```elixir\niex> RingLogger.detach\n:ok\niex> Logger.info(\"Hello logger, how are you?\")\n:ok\niex> Logger.info(\"It's a nice day. Wouldn't you say?\")\n:ok\niex> RingLogger.next\n\n14:04:52.516 [info]  hello\n\n14:11:54.397 [info]  Hello logger, how are you?\n\n14:12:09.180 [info]  It's a nice day. Wouldn't you say?\n:ok\niex> RingLogger.next\n:ok\n```\n\nIf you only want to see the most recent entries, run `tail`:\n\n```elixir\niex> RingLogger.tail\n\n14:04:52.516 [info]  hello\n\n14:11:54.397 [info]  Hello logger, how are you?\n\n14:12:09.180 [info]  It's a nice day. Wouldn't you say?\n:ok\n```\n\nYou can also `grep`:\n\n```elixir\niex> RingLogger.grep(~r/[Nn]eedle/)\n\n16:55:41.614 [info]  Needle in a haystack\n```","ref":"readme.html#iex-session-usage"},{"type":"extras","title":"RingLogger TUI - ring_logger","doc":"RingLogger provides a simple text UI that lets you access log viewing features\nin a friendly way.\n\n[![asciicast](https://asciinema.org/a/620485.svg)](https://asciinema.org/a/620485)\n\n```elixir\niex> RingLogger.viewer()\n```\n\nType `h` and then enter for help.","ref":"readme.html#ringlogger-tui"},{"type":"extras","title":"Module and Application Level Filtering - ring_logger","doc":"If you want to filter a module or modules at a particular level you pass a map\nwhere the key is the module name and value in the level into the\n`:module_levels` option to `RingLogger.attach/1`.\n\nFor example:\n\n```elixir\niex> RingLogger.attach(module_levels: %{MyModule => :info})\n```\n\nThis will ignore all the `:debug` messages from `MyModule`.\n\nAlso, it allows for filtering the whole project on a higher level, but a\nparticular module, or a subset of modules, to log at a lower level like so:\n\n```elixir\niex> RingLogger.attach(module_levels: %{MyModule => :debug}, level: :warn)\n```\n\nIn the example above log messages at the `:debug` level will be logged, but\nevery other module will be logging at the `:warn` level. You can also turn off a\nmodule's logging completely by specifying `:none`.\n\nAdditionally, you can specify the same options at the application level to\ndisable logging for all its modules using the `:application_levels` option\nwith OTP application names as the key:\n\n```elixir\niex> RingLogger.attach(application_levels: %{my_app: :info})\n```\n\n`module_levels` takes precedence in the case of including both module and\napplication level filtering:\n\n```elixir\niex> RingLogger.attach(application_levels: %{my_app: :info}, module_levels: %{MyApp.Important => :debug})\n```\n\nIn the above example, all modules of `:my_app` with have a level of `:info` except\nfor `MyApp.Important`, which will have a level of `:debug`.\n\nAs a note if the Elixir `Logger` level is set too low you will miss some log\nmessages.","ref":"readme.html#module-and-application-level-filtering"},{"type":"extras","title":"Saving the log - ring_logger","doc":"By design, `RingLogger` doesn't save logs. It can be convenient to share the\ncurrent log buffer for later analysis:\n\n```elixir\niex> RingLogger.save(\"/tmp/log.txt\")\n:ok\n```\n\nLog messages are formatted the same way as the `RingLogger` functions that\noutput to the console.","ref":"readme.html#saving-the-log"},{"type":"extras","title":"Formatting - ring_logger","doc":"If you want to use a specific string format with the built in Elixir\nLogger.Formatter, you can pass that as the `:format` option to\n`RingLogger.attach/1`.\n\nIf you want to use a custom formatter function, you can pass it through the\n`:format` option to `RingLogger.attach/1` instead.\n\nFor example, to print the file and line number of each log message, you could\ndefine a function as follows:\n\n```elixir\ndefmodule CustomFormatter do\n  def format(_level, message, _timestamp, metadata) do\n    \"#{message} #{metadata[:file]}:#{metadata[:line]}\\n\"\n  rescue\n    _ -> message\n  end\nend\n```\n\nand attach to the RingLogger with:\n\n```elixir\niex> RingLogger.attach(format: {CustomFormatter, :format}, metadata: [:file, :line])\n:ok\niex> require Logger\nLogger\niex> Logger.info(\"Important message!\")\n:ok\nImportant message! iex:4\n```\n\nWithin an application, the `iex:4` would be the source file path and line number.\n\nSee [Logger custom formatting](https://hexdocs.pm/logger/Logger.html#module-custom-formatting)\nfor more information.","ref":"readme.html#formatting"},{"type":"extras","title":"Programmatic usage - ring_logger","doc":"It can be useful to get a snapshot of the log when an unexpected event occurs.\nThe commandline functions demonstrated above are available, but you can also get\nthe raw log entries by calling `RingLogger.get/0`:\n\n```elixir\niex> RingLogger.get\n[\n  debug: {Logger, \"8\", {{2018, 2, 5}, {17, 44, 7, 675}},\n   [\n     pid: #PID<0.139.0>,\n     application: :example,\n     module: Example,\n     function: \"log/1\",\n     file: \"ring_logger/example/lib/example.ex\",\n     line: 11\n   ]},\n  debug: {Logger, \"9\", {{2018, 2, 5}, {17, 44, 8, 676}},\n   [\n     pid: #PID<0.139.0>,\n     application: :example,\n     module: Example,\n     function: \"log/1\",\n     file: \"ring_logger/example/lib/example.ex\",\n     line: 11\n   ]},\n  debug: {Logger, \"10\", {{2018, 2, 5}, {17, 44, 9, 677}},\n   [\n     pid: #PID<0.139.0>,\n     application: :example,\n     module: Example,\n     function: \"log/1\",\n     file: \"ring_logger/example/lib/example.ex\",\n     line: 11\n   ]}\n]\n```","ref":"readme.html#programmatic-usage"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nThis project follows [Semantic Versioning](https://semver.org/spec/v2.0.0.html).","ref":"changelog.html"},{"type":"extras","title":"v0.11.2 - Changelog","doc":"* Fixes\n  * Don't crash when logging corrupt data. This is not common, but can caused\n    when logging output from system commands.","ref":"changelog.html#v0-11-2"},{"type":"extras","title":"v0.11.1 - Changelog","doc":"* Fixes\n  * Fix minor pagination issues with viewer\n  * Adjust boot start search string to work with more Nerves systems","ref":"changelog.html#v0-11-1"},{"type":"extras","title":"v0.11.0 - Changelog","doc":"* New features\n  * Add small TUI. Run `RingLogger.viewer` and type `h` for help to try it out.\n    Thanks to @doawoo for this feature.","ref":"changelog.html#v0-11-0"},{"type":"extras","title":"v0.10.5 - Changelog","doc":"* Fixes\n  * Reset potentially outdated indexes when persisted logs are loaded. Fixes\n    the case where the persisted logs might have a much higher index than the\n    current buffer, so every new log gets added before the loaded logs","ref":"changelog.html#v0-10-5"},{"type":"extras","title":"v0.10.4 - Changelog","doc":"* Fixes\n  * History from loaded persistance file would be reset and lost if multiple\n    buffers were configured outside the default buffer when RingLogger was\n    reconfigured (at startup or runtime)","ref":"changelog.html#v0-10-4"},{"type":"extras","title":"v0.10.3 - Changelog","doc":"* Improvements\n  * Add ability to grep text of a metadata key (thanks @levex! :heart:).\n    See `RingLogger.grep_metadata/2` for more info.","ref":"changelog.html#v0-10-3"},{"type":"extras","title":"v0.10.2 - Changelog","doc":"* Fixes\n  * Fix remaining Elixir 1.15 warnings","ref":"changelog.html#v0-10-2"},{"type":"extras","title":"v0.10.1 - Changelog","doc":"* Improvements\n  * Add guards to prevent some bad API inputs from crashing in places\n    disconnected from the original calls.","ref":"changelog.html#v0-10-1"},{"type":"extras","title":"v0.10.0 - Changelog","doc":"This latest release removes support for Elixir versions before 1.11 to fix\ndeprecation warnings on Elixir 1.15. Elixir 1.11 to 1.14 are officially\nsupported and Elixir 1.15 will be supported when released.\n\n* Improvements\n  * Support for syncing the RingBuffer to disk at periodic intervals. This\n    provides an option between a standard file logger and a fully in-memory log.\n    This doesn't provide additional history, but does enable logs to survive\n    reboots (assuming they were saved). It's disabled by default. See the\n    `:persist_path` and `:persist_seconds` options for details. Thanks to\n    @oestrich for adding this feature.","ref":"changelog.html#v0-10-0"},{"type":"extras","title":"v0.9.0 - Changelog","doc":"This latest release removes support for Elixir versions before 1.9.\n\n* Improvements\n  * Support multiple circular buffers and filtering based on log level. This\n    makes it possible to separate out debug and info messages so they don't push\n    out error messages. See the `README.md` for configuration examples. Thanks\n    to @oestrich for this feature.\n  * Fixed and added specs throughout","ref":"changelog.html#v0-9-0"},{"type":"extras","title":"v0.8.6 - Changelog","doc":"* Improvements\n  * Fixed crashes when converting unicode chardata. Thanks to @x4lldux for this\n    fix.","ref":"changelog.html#v0-8-6"},{"type":"extras","title":"v0.8.5 - Changelog","doc":"* Improvements\n  * `RingLogger.grep/2` supports `:before` and `:after` options\n  * Support OTP 25","ref":"changelog.html#v0-8-5"},{"type":"extras","title":"v0.8.4 - Changelog","doc":"* Fixes\n  * Default color enabled option now correctly evaluated at runtime for the active IO\n\n* Improvements\n  * `RingLogger.grep` will now highlight matches in the output if color is enabled","ref":"changelog.html#v0-8-4"},{"type":"extras","title":"v0.8.3 - Changelog","doc":"* Fixes\n  * Pull all application environment configuration from `:logger, RingLogger`\n    rather than some from there and some from `:ring_logger`. Adding\n    configuration under `:ring_logger` is still supported, but prints a\n    deprecation warning. Thanks to Jason Axelson for this fix.","ref":"changelog.html#v0-8-3"},{"type":"extras","title":"v0.8.2 - Changelog","doc":"* Improvements\n  * Circular buffer improvements are all upstream in the `circular_buffer`\n    library, so this release makes it official by deleting the internal\n    implementation and using the hex package.","ref":"changelog.html#v0-8-2"},{"type":"extras","title":"v0.8.1 - Changelog","doc":"* New features\n  * `RingLogger.next/1` now outputs a summary line that says how many log\n    messages were recented and how many were filtered. This makes it easier to\n    identify when the ring buffer is being overtaken by filtered log entries\n\n* Improvements\n  * Several internal refactorings were made to reduce memory usage and\n    the number of reductions run in the `RingLogger.Server` GenServer. This\n    makes a noticeable improvement when monitoring resource usage on a device.\n  * Improved tests to verify more edge conditions","ref":"changelog.html#v0-8-1"},{"type":"extras","title":"v0.8.0 - Changelog","doc":"* New features\n  * Support filtering by OTP application. This uses the same mechanism as\n    per-module filtering by automatically adding in all modules that are part of\n    an OTP application. It is super useful! See the README.md. Thanks to Jon\n    Carstons for adding this feature.\n  * Support setting defaults on RingLogger clients so that you can configure\n    things like a global default to info level messages and then only show\n    debug messages from some applications","ref":"changelog.html#v0-8-0"},{"type":"extras","title":"v0.7.0 - Changelog","doc":"* New features\n  * Added `save/1` to save the current set of log messages in the ring buffer to\n    a file","ref":"changelog.html#v0-7-0"},{"type":"extras","title":"v0.6.1 - Changelog","doc":"* Bug fixes\n  * Make `RingLogger.grep` friendlier by supporting strings as arguments","ref":"changelog.html#v0-6-1"},{"type":"extras","title":"v0.6.0 - Changelog","doc":"Important: `RingLogger.tail` is now `RingLogger.next`. `RingLogger.tail` shows\nthe last n lines of the log (default is 10).\n\n* New features\n  * `grep` greps the whole log entry rather than just the message portion. You\n    can `grep` on timestamps and message levels now.\n  * Functions that print log messages do the printing in the caller's context so\n    that printing timeouts don't happen in RingLogger GenServers calls.\n  * Added `:none` as a per-module log level to completely silence a module.\n  * Added `:pager` option to specify a custom printer for the interactive\n    commands.","ref":"changelog.html#v0-6-0"},{"type":"extras","title":"v0.5.0 - Changelog","doc":"* New features\n  * Add support for changing the log levels on a per-module basis. Thanks to\n    Matt Ludwigs for this change. See the README.md for details.\n  * Add a `:format` option to accept a custom format function similar to how\n    `Logger` supports custom formatting. Thanks to Tim Mecklem for this.\n  * Bumped default ring buffer size from 100 messages to 1024.\n\n* Bug fixes\n  * Log clients are now fully configurable. Previous versions inadvertantly\n    limited the options that could be set.","ref":"changelog.html#v0-5-0"},{"type":"extras","title":"v0.4.1 - Changelog","doc":"* Bug fixes\n  * Fix crash when `grep`'ing iodata\n  * Fix `init/1` callback return value when only specifying the module.","ref":"changelog.html#v0-4-1"},{"type":"extras","title":"v0.4.0 - Changelog","doc":"* New features\n  * Added `grep`\n  * Automatically add the backend if it's not running when using the IEx helpers","ref":"changelog.html#v0-4-0"},{"type":"extras","title":"v0.3.0 - Changelog","doc":"Renamed `LoggerCircularBuffer` to `RingLogger` and made backwards incompatible\nAPI changes. Please review docs when upgrading.\n\n* New features\n  * Simplified use from IEx by autostarting the Client GenServer\n  * Added support for `tail`ing logs","ref":"changelog.html#v0-3-0"},{"type":"extras","title":"v0.2.0 - Changelog","doc":"Renamed `LoggerCircularBuffer` to `LoggerCircularBuffer`","ref":"changelog.html#v0-2-0"},{"type":"extras","title":"v0.1.0 - Changelog","doc":"Initial release","ref":"changelog.html#v0-1-0"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}